@@ -16,9 +16,7 @@ use Storable qw(store_fd retrieve_fd);
 
 our @ISA = qw(LWP::UserAgent);
 
-our $VERSION = '1.18';
-
-
+our $VERSION = '1.27';
 
 sub new {
     my $class = shift;
@@ -72,6 +70,7 @@ sub new {
         else {
 
             carp "OAuth calls must have at least a consumer_key and a consumer_secret";
+            $self->_set_status(0,"OAuth call without consumer_secret");
 
         }
 
@@ -112,10 +111,10 @@ sub new {
         $self->{auth_uri}    = $options->{auth_uri} || 'https://api.flickr.com/services/auth/';
         $self->{unicode}     = $options->{unicode}  || 0;
 
-        $self->{flickr}->{frob}    = $options->{frob};
-        $self->{flickr}->{key}     = $options->{key};
-        $self->{flickr}->{secret}  = $options->{secret};
-        $self->{flickr}->{token}   = $options->{token};
+        $self->{fauth}->{frob}    = $options->{frob};
+        $self->{fauth}->{key}     = $options->{key};
+        $self->{fauth}->{secret}  = $options->{secret};
+        $self->{fauth}->{token}   = $options->{token};
 
         carp "You must pass an API key or a Consumer key to the constructor" unless defined $self->{api_key};
 
@@ -128,6 +127,7 @@ sub new {
     };
 
     bless $self, $class;
+    $self->_clear_status();
     $self->_initialize();
     return $self;
 }
@@ -309,7 +309,7 @@ sub export_config {
         }
     }
     else {
-        return %{$self->{flickr}};
+        return %{$self->{fauth}};
     }
 
 }
@@ -539,12 +539,12 @@ sub flickr_access_token {
     my $rsp = $self->execute_method('flickr.auth.getToken', {api_key => $self->{api_key}, frob => $frob });
     my $response_ref = $rsp->as_hash();
 
-    $self->{flickr}->{frob} = $frob;
+    $self->{fauth}->{frob} = $frob;
 
     $self->{token} = $response_ref->{auth}->{token};
-    $self->{flickr}->{token} = $response_ref->{auth}->{token};
+    $self->{fauth}->{token} = $response_ref->{auth}->{token};
 
-    $self->{flickr}->{user}  = $response_ref->{auth}->{user};
+    $self->{fauth}->{user}  = $response_ref->{auth}->{user};
 
     return $response_ref->{stat};
 
@@ -578,6 +578,18 @@ sub get_oauth_request_type {
     }
 }
 
+sub api_success {
+    my $self = shift;
+
+    return $self->{flickr}->{status}->{api_success};
+
+}
+sub api_message {
+    my $self = shift;
+
+    return $self->{flickr}->{status}->{api_message};
+}
+
 
 #
 # Private methods
@@ -619,9 +631,68 @@ sub _make_nonce {
     return md5_hex(rand);
 
 }
+sub _export_api {
+    my $self = shift;
+    my $api  = {};
+
+    $api->{oauth}       = $self->{oauth};
+    $api->{fauth}       = $self->{fauth};
+    $api->{flickr}      = $self->{flickr};
+
+    $api->{api_type}    =  $self->{api_type};
+    $api->{api_key}     =  $self->{api_key};
+    $api->{api_secret}  =  $self->{api_secret};
+    $api->{rest_uri}    =  $self->{rest_uri};
+    $api->{unicode}     =  $self->{unicode};
+    $api->{auth_uri}    =  $self->{auth_uri};
+
+    return $api;
+}
 
 
-sub _initialize {}
+sub _initialize {
+
+    my $self = shift;
+    $self->_set_status(1,'Base API initialized');
+
+}
+
+sub _full_status {
+
+    my $self = shift;
+    return $self->{flickr}->{status};
+}
+
+sub _clear_status {
+
+    my $self = shift;
+
+    # the API status
+    $self->_set_status(1,'');
+    # the propagated response status
+    $self->{flickr}->{status}->{_rc} = 0;
+    $self->{flickr}->{status}->{success} = 1;         # initialize as successful
+    $self->{flickr}->{status}->{error_code} = 0;
+    $self->{flickr}->{status}->{error_message} = '';
+
+    return;
+
+}
+
+sub _set_status {
+
+    my $self  =  shift;
+    my $good  =  shift;
+    my $msg   =  shift;
+
+    if ($good != 0) { $good = 1; }
+
+    $self->{flickr}->{status}->{api_success} = $good;
+    $self->{flickr}->{status}->{api_message} = $msg;
+
+    return;
+}
+
 
 
 1;
